@@ -22,6 +22,7 @@ the classes contained therein.
 
 import collections
 import copy
+from importlib import import_module
 import inspect
 import logging
 import os
@@ -30,21 +31,21 @@ import django
 from django.conf import settings
 from django.conf.urls import include
 from django.conf.urls import url
-from django.core.exceptions import ImproperlyConfigured  # noqa
+from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import reverse
 from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import empty
-from django.utils.functional import SimpleLazyObject  # noqa
-from django.utils.module_loading import module_has_submodule  # noqa
+from django.utils.functional import SimpleLazyObject
+from django.utils.module_loading import module_has_submodule
 from django.utils.translation import ugettext_lazy as _
-from importlib import import_module
 import six
 
 from horizon import conf
-from horizon.decorators import _current_component  # noqa
-from horizon.decorators import require_auth  # noqa
-from horizon.decorators import require_perms  # noqa
+from horizon.decorators import _current_component
+from horizon.decorators import require_auth
+from horizon.decorators import require_perms
 from horizon import loaders
+from horizon.utils import settings as utils_settings
 
 
 # Name of the panel group for panels to be displayed without a group.
@@ -144,7 +145,7 @@ class HorizonComponent(object):
         return self._can_access(context['request'])
 
     def _can_access(self, request):
-        policy_check = getattr(settings, "POLICY_CHECK_FUNCTION", None)
+        policy_check = utils_settings.import_setting("POLICY_CHECK_FUNCTION")
 
         # this check is an OR check rather than an AND check that is the
         # default in the policy engine, so calling each rule individually
@@ -263,7 +264,7 @@ class Panel(HorizonComponent):
     .. attribute:: nav
     .. method:: nav(context)
 
-        The ``nav`` attribute can be either boolean value or a callable
+        The ``nav`` attribute can be either a boolean value or a callable
         which accepts a ``RequestContext`` object as a single argument
         to control whether or not this panel should appear in
         automatically-generated navigation. Default: ``True``.
@@ -308,7 +309,8 @@ class Panel(HorizonComponent):
         except Exception as exc:
             # Logging here since this will often be called in a template
             # where the exception would be hidden.
-            LOG.info("Error reversing absolute URL for %s: %s" % (self, exc))
+            LOG.info("Error reversing absolute URL for %(self)s: %(exc)s",
+                     {'self': self, 'exc': exc})
             raise
 
     @property
@@ -441,7 +443,7 @@ class Dashboard(Registry, HorizonComponent):
     .. attribute:: nav
     .. method:: nav(context)
 
-        The ``nav`` attribute can be either boolean value or a callable
+        The ``nav`` attribute can be either a boolean value or a callable
         which accepts a ``RequestContext`` object as a single argument
         to control whether or not this dashboard should appear in
         automatically-generated navigation. Default: ``True``.
@@ -469,14 +471,13 @@ class Dashboard(Registry, HorizonComponent):
         self._panel_groups = None
 
     def get_panel(self, panel):
-        """Returns the specified :class:`~horizon.Panel` instance registered
-        with this dashboard.
-        """
+        """Returns the Panel instance registered with this dashboard."""
         return self._registered(panel)
 
     def get_panels(self):
-        """Returns the :class:`~horizon.Panel` instances registered with this
-        dashboard in order, without any panel groupings.
+        """Returns the Panel instances registered with this dashboard in order.
+
+        Panel grouping information is not included.
         """
         all_panels = []
         panel_groups = self.get_panel_groups()
@@ -485,8 +486,9 @@ class Dashboard(Registry, HorizonComponent):
         return all_panels
 
     def get_panel_group(self, slug):
-        """Returns the specified :class:~horizon.PanelGroup
-        or None if not registered
+        """Returns the specified :class:~horizon.PanelGroup.
+
+        Returns None if not registered.
         """
         return self._panel_groups.get(slug)
 
@@ -523,7 +525,7 @@ class Dashboard(Registry, HorizonComponent):
         except Exception:
             # Logging here since this will often be called in a template
             # where the exception would be hidden.
-            LOG.exception("Error reversing absolute URL for %s." % self)
+            LOG.exception("Error reversing absolute URL for %s.", self)
             raise
 
     @property
@@ -1004,8 +1006,10 @@ class Site(Registry, HorizonComponent):
 
 
 class HorizonSite(Site):
-    """A singleton implementation of Site such that all dealings with horizon
-    get the same instance no matter what. There can be only one.
+    """A singleton implementation of Site.
+
+    All dealings with horizon get the same instance no matter what.
+    There can be only one.
     """
     _instance = None
 
