@@ -16,8 +16,6 @@ import functools
 import warnings
 import weakref
 
-import six
-
 
 class UnhashableKeyWarning(RuntimeWarning):
     """Raised when trying to memoize a function with an unhashable argument."""
@@ -42,7 +40,7 @@ def _get_key(args, kwargs, remove_callback):
     # Sort it, so that we don't depend on the order of keys.
     weak_kwargs = tuple(sorted(
         (key, _try_weakref(value, remove_callback))
-        for (key, value) in six.iteritems(kwargs)))
+        for (key, value) in kwargs.items()))
     return weak_args, weak_kwargs
 
 
@@ -132,7 +130,7 @@ def memoized_with_request(request_func, request_index=0):
     request, and thus the memoizing will operate just on that part of the
     request that is relevant to the function being memoized.
 
-    short example:
+    short example::
 
         @memoized
         def _get_api_client(username, token_id, project_id, auth_url)
