@@ -20,15 +20,18 @@ import logging
 
 from oslo_utils import units
 
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
+from horizon import messages
 from horizon import tables
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.images.images import views
+from openstack_dashboard import policy
 
 from openstack_dashboard.dashboards.admin.images import forms as project_forms
 from openstack_dashboard.dashboards.admin.images \
@@ -39,8 +42,8 @@ LOG = logging.getLogger(__name__)
 
 
 class IndexView(tables.DataTableView):
+    DEFAULT_FILTERS = {'is_public': None}
     table_class = project_tables.AdminImagesTable
-    template_name = 'admin/images/index.html'
     page_title = _("Images")
 
     def has_prev_data(self, table):
@@ -49,9 +52,28 @@ class IndexView(tables.DataTableView):
     def has_more_data(self, table):
         return self._more
 
+    def needs_filter_first(self, table):
+        return self._needs_filter_first
+
     def get_data(self):
         images = []
+
+        if not policy.check((("image", "get_images"),), self.request):
+            msg = _("Insufficient privilege level to retrieve image list.")
+            messages.info(self.request, msg)
+            return images
         filters = self.get_filters()
+
+        filter_first = getattr(settings, 'FILTER_DATA_FIRST', {})
+        if filter_first.get('admin.images', False) and \
+                len(filters) == len(self.DEFAULT_FILTERS):
+            self._prev = False
+            self._more = False
+            self._needs_filter_first = True
+            return images
+
+        self._needs_filter_first = False
+
         prev_marker = self.request.GET.get(
             project_tables.AdminImagesTable._meta.prev_pagination_param, None)
 
@@ -91,23 +113,27 @@ class IndexView(tables.DataTableView):
         return images
 
     def get_filters(self):
-        filters = {'is_public': None}
+        filters = self.DEFAULT_FILTERS.copy()
         filter_field = self.table.get_filter_field()
         filter_string = self.table.get_filter_string()
         filter_action = self.table._meta._filter_action
         if filter_field and filter_string and (
                 filter_action.is_api_filter(filter_field)):
             if filter_field in ['size_min', 'size_max']:
-                invalid_msg = ('API query is not valid and is ignored: %s=%s'
-                               % (filter_field, filter_string))
+                invalid_msg = ('API query is not valid and is ignored: '
+                               '%(field)s=%(string)s')
                 try:
                     filter_string = long(float(filter_string) * (units.Mi))
                     if filter_string >= 0:
                         filters[filter_field] = filter_string
                     else:
-                        LOG.warning(invalid_msg)
+                        LOG.warning(invalid_msg,
+                                    {'field': filter_field,
+                                     'string': filter_string})
                 except ValueError:
-                    LOG.warning(invalid_msg)
+                    LOG.warning(invalid_msg,
+                                {'field': filter_field,
+                                 'string': filter_string})
             elif (filter_field == 'disk_format' and
                   filter_string.lower() == 'docker'):
                 filters['disk_format'] = 'raw'
