@@ -17,6 +17,7 @@ from django.core import urlresolvers
 from django.template.defaultfilters import title
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
+from keystoneclient import exceptions as keystone_exceptions
 
 from horizon import tables
 from horizon.utils import filters
@@ -26,6 +27,7 @@ from openstack_dashboard.dashboards.project.instances import audit_tables
 from openstack_dashboard.dashboards.project.instances \
     import tables as project_tables
 from openstack_dashboard import policy
+from openstack_dashboard.views import get_url_with_pagination
 
 
 class AdminEditInstance(project_tables.EditInstance):
@@ -89,10 +91,14 @@ class LiveMigrateInstance(policy.PolicyTargetMixin,
 class AdminUpdateRow(project_tables.UpdateRow):
     def get_data(self, request, instance_id):
         instance = super(AdminUpdateRow, self).get_data(request, instance_id)
-        tenant = api.keystone.tenant_get(request,
-                                         instance.tenant_id,
-                                         admin=True)
-        instance.tenant_name = getattr(tenant, "name", None)
+        try:
+            tenant = api.keystone.tenant_get(request,
+                                             instance.tenant_id,
+                                             admin=True)
+            instance.tenant_name = getattr(tenant, "name", instance.tenant_id)
+        except keystone_exceptions.NotFound:
+            instance.tenant_name = None
+
         return instance
 
 
@@ -109,6 +115,13 @@ class AdminInstanceFilterAction(tables.FilterAction):
     ) + project_tables.INSTANCE_FILTER_CHOICES
 
 
+def get_server_detail_link(obj, request):
+    return get_url_with_pagination(
+        request, AdminInstancesTable._meta.pagination_param,
+        AdminInstancesTable._meta.prev_pagination_param,
+        "horizon:admin:instances:detail", obj.id)
+
+
 class AdminInstancesTable(tables.DataTable):
     TASK_STATUS_CHOICES = (
         (None, True),
@@ -134,7 +147,7 @@ class AdminInstancesTable(tables.DataTable):
                          verbose_name=_("Host"),
                          classes=('nowrap-col',))
     name = tables.WrappingColumn("name",
-                                 link="horizon:admin:instances:detail",
+                                 link=get_server_detail_link,
                                  verbose_name=_("Name"))
     image_name = tables.Column("image_name",
                                verbose_name=_("Image Name"))
