@@ -18,8 +18,7 @@ import uuid
 from django.core.urlresolvers import reverse
 from django import http
 
-from mox3.mox import IgnoreArg  # noqa
-from mox3.mox import IsA  # noqa
+from mox3.mox import IsA
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
@@ -47,12 +46,12 @@ class InstanceViewTest(test.BaseAdminViewTests):
             .MultipleTimes().AndReturn(True)
         api.keystone.tenant_list(IsA(http.HttpRequest)).\
             AndReturn([tenants, False])
-        search_opts = {'marker': None, 'paginate': True}
+        search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         api.glance.image_list_detailed(IsA(http.HttpRequest))\
             .AndReturn(images)
         api.nova.flavor_list(IsA(http.HttpRequest)).AndReturn(flavors)
         api.nova.server_list(IsA(http.HttpRequest),
-                             all_tenants=True, search_opts=search_opts) \
+                             search_opts=search_opts) \
             .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
@@ -75,9 +74,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
         tenants = self.tenants.list()
         flavors = self.flavors.list()
         full_flavors = OrderedDict([(f.id, f) for f in flavors])
-        search_opts = {'marker': None, 'paginate': True}
+        search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         api.nova.server_list(IsA(http.HttpRequest),
-                             all_tenants=True, search_opts=search_opts) \
+                             search_opts=search_opts) \
             .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
@@ -120,9 +119,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
         api.glance.image_list_detailed(IsA(http.HttpRequest))\
             .AndReturn(images)
         api.nova.flavor_list(IsA(http.HttpRequest)).AndReturn(flavors)
-        search_opts = {'marker': None, 'paginate': True}
+        search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         api.nova.server_list(IsA(http.HttpRequest),
-                             all_tenants=True, search_opts=search_opts) \
+                             search_opts=search_opts) \
             .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
@@ -141,9 +140,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
         instances = res.context['table'].data
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         # Since error messages produced for each instance are identical,
-        # there will be only one error message for all instances
+        # there will be only two error messages for all instances
         # (messages de-duplication).
-        self.assertMessageCount(res, error=1)
+        self.assertMessageCount(res, error=2)
         self.assertItemsEqual(instances, servers)
 
     @test.create_stubs({
@@ -154,9 +153,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
     def test_index_server_list_exception(self):
         tenants = self.tenants.list()
 
-        search_opts = {'marker': None, 'paginate': True}
+        search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         api.nova.server_list(IsA(http.HttpRequest),
-                             all_tenants=True, search_opts=search_opts) \
+                             search_opts=search_opts) \
             .AndRaise(self.exceptions.nova)
         api.keystone.tenant_list(IsA(http.HttpRequest)).\
             AndReturn([tenants, False])
@@ -220,9 +219,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
         api.glance.image_list_detailed(IsA(http.HttpRequest)) \
             .AndReturn(images)
         api.nova.flavor_list(IsA(http.HttpRequest)).AndReturn(flavors)
-        search_opts = {'marker': None, 'paginate': True}
+        search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         api.nova.server_list(IsA(http.HttpRequest),
-                             all_tenants=True, search_opts=search_opts) \
+                             search_opts=search_opts) \
             .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
@@ -256,13 +255,13 @@ class InstanceViewTest(test.BaseAdminViewTests):
         api.glance.image_list_detailed(IsA(http.HttpRequest)) \
             .AndReturn(images)
         api.nova.flavor_list(IsA(http.HttpRequest)).AndReturn(flavors)
-        search_opts = {'marker': None, 'paginate': True}
+        search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         api.nova.extension_supported('AdminActions', IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(True)
         api.nova.extension_supported('Shelve', IsA(http.HttpRequest)) \
             .MultipleTimes().AndReturn(True)
         api.nova.server_list(IsA(http.HttpRequest),
-                             all_tenants=True, search_opts=search_opts) \
+                             search_opts=search_opts) \
             .AndReturn([servers, False])
         api.network.servers_update_addresses(IsA(http.HttpRequest), servers,
                                              all_tenants=True)
@@ -372,7 +371,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
                                    'server_live_migrate',)})
     def test_instance_live_migrate_auto_sched(self):
         server = self.servers.first()
-        host = ""
+        host = "AUTO_SCHEDULE"
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
             .AndReturn(server)
         api.nova.host_list(IsA(http.HttpRequest)) \
