@@ -54,9 +54,10 @@ class DeleteSubnet(proj_tables.SubnetPolicyTargetMixin, tables.DeleteAction):
     def delete(self, request, obj_id):
         try:
             api.neutron.subnet_delete(request, obj_id)
-        except Exception:
+        except Exception as e:
+            LOG.info('Failed to delete subnet %(id)s: %(exc)s',
+                     {'id': obj_id, 'exc': e})
             msg = _('Failed to delete subnet %s') % obj_id
-            LOG.info(msg)
             network_id = self.table.kwargs['network_id']
             redirect = reverse('horizon:admin:networks:detail',
                                args=[network_id])
@@ -66,7 +67,7 @@ class DeleteSubnet(proj_tables.SubnetPolicyTargetMixin, tables.DeleteAction):
 class CreateSubnet(proj_tables.SubnetPolicyTargetMixin, tables.LinkAction):
     name = "create"
     verbose_name = _("Create Subnet")
-    url = "horizon:admin:networks:addsubnet"
+    url = "horizon:admin:networks:createsubnet"
     classes = ("ajax-modal",)
     icon = "plus"
     policy_rules = (("network", "create_subnet"),)
@@ -113,7 +114,7 @@ class SubnetsTable(tables.DataTable):
     failure_url = reverse_lazy('horizon:admin:networks:index')
 
     def get_object_display(self, subnet):
-        return subnet.id
+        return subnet.name_or_id
 
     @memoized.memoized_method
     def _get_network(self):
