@@ -19,13 +19,13 @@
 import tempfile
 
 from django.conf import settings
-from django.core.files.uploadedfile import InMemoryUploadedFile  # noqa
+from django.core.files.uploadedfile import InMemoryUploadedFile
 from django.core.urlresolvers import reverse
-from django.forms.widgets import HiddenInput  # noqa
+from django.forms.widgets import HiddenInput
 from django import http
 from django.test.utils import override_settings
 
-from mox3.mox import IsA  # noqa
+from mox3.mox import IsA
 
 from horizon import tables as horizon_tables
 from openstack_dashboard import api
@@ -38,7 +38,7 @@ from openstack_dashboard.dashboards.project.images.images import tables
 IMAGES_INDEX_URL = reverse('horizon:project:images:index')
 
 
-class CreateImageFormTests(test.TestCase):
+class CreateImageFormTests(test.ResetImageAPIVersionMixin, test.TestCase):
     @test.create_stubs({api.glance: ('image_list_detailed',)})
     def test_no_location_or_file(self):
         filters = {'disk_format': 'aki'}
@@ -64,6 +64,7 @@ class CreateImageFormTests(test.TestCase):
         self.assertFalse(form.is_valid())
 
     @override_settings(HORIZON_IMAGES_ALLOW_UPLOAD=False)
+    @override_settings(IMAGES_ALLOW_LOCATION=True)
     @test.create_stubs({api.glance: ('image_list_detailed',)})
     def test_image_upload_disabled(self):
         filters = {'disk_format': 'aki'}
@@ -81,7 +82,8 @@ class CreateImageFormTests(test.TestCase):
         source_type_dict = dict(form.fields['source_type'].choices)
         self.assertNotIn('file', source_type_dict)
 
-    def test_create_image_metadata_docker(self):
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
+    def test_create_image_metadata_docker_v1(self):
         form_data = {
             'name': u'Docker image',
             'description': u'Docker image test',
@@ -106,8 +108,29 @@ class CreateImageFormTests(test.TestCase):
         self.assertEqual(meta['properties']['architecture'],
                          form_data['architecture'])
 
+    def test_create_image_metadata_docker_v2(self):
+        form_data = {
+            'name': u'Docker image',
+            'description': u'Docker image test',
+            'source_type': u'url',
+            'image_url': u'/',
+            'disk_format': u'docker',
+            'architecture': u'x86-64',
+            'minimum_disk': 15,
+            'minimum_ram': 512,
+            'is_public': False,
+            'protected': False,
+            'is_copying': False
+        }
+        meta = forms.create_image_metadata(form_data)
+        self.assertEqual(meta['disk_format'], 'raw')
+        self.assertEqual(meta['container_format'], 'docker')
+        self.assertNotIn('properties', meta)
+        self.assertEqual(meta['description'], form_data['description'])
+        self.assertEqual(meta['architecture'], form_data['architecture'])
 
-class UpdateImageFormTests(test.TestCase):
+
+class UpdateImageFormTests(test.ResetImageAPIVersionMixin, test.TestCase):
     def test_is_format_field_editable(self):
         form = forms.UpdateImageForm({})
         disk_format = form.fields['disk_format']
@@ -127,8 +150,9 @@ class UpdateImageFormTests(test.TestCase):
         self.assertEqual(res.context['image'].disk_format,
                          image.disk_format)
 
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
     @test.create_stubs({api.glance: ('image_update', 'image_get')})
-    def test_image_update_post(self):
+    def test_image_update_post_v1(self):
         image = self.images.first()
         data = {
             'name': u'Ubuntu 11.10',
@@ -156,10 +180,49 @@ class UpdateImageFormTests(test.TestCase):
                                 name=data['name'],
                                 min_ram=data['minimum_ram'],
                                 min_disk=data['minimum_disk'],
-                                properties={'description': data['description'],
-                                            'architecture':
-                                            data['architecture']},
-                                purge_props=False).AndReturn(image)
+                                properties={
+                                    'description': data['description'],
+                                    'architecture':
+                                    data['architecture']}).AndReturn(image)
+        self.mox.ReplayAll()
+        url = reverse('horizon:project:images:images:update',
+                      args=[image.id])
+        res = self.client.post(url, data)
+        self.assertNoFormErrors(res)
+        self.assertEqual(res.status_code, 302)
+
+    @test.create_stubs({api.glance: ('image_update', 'image_get')})
+    def test_image_update_post_v2(self):
+        image = self.images.first()
+        data = {
+            'name': u'Ubuntu 11.10',
+            'image_id': str(image.id),
+            'description': u'Login with admin/admin',
+            'source_type': u'url',
+            'image_url': u'http://cloud-images.ubuntu.com/releases/'
+                         u'oneiric/release/ubuntu-11.10-server-cloudimg'
+                         u'-amd64-disk1.img',
+            'disk_format': u'qcow2',
+            'architecture': u'x86-64',
+            'minimum_disk': 15,
+            'minimum_ram': 512,
+            'is_public': False,
+            'protected': False,
+            'method': 'UpdateImageForm'}
+        api.glance.image_get(IsA(http.HttpRequest), str(image.id)) \
+            .AndReturn(image)
+        api.glance.image_update(IsA(http.HttpRequest),
+                                image.id,
+                                visibility='private',
+                                protected=data['protected'],
+                                disk_format=data['disk_format'],
+                                container_format="bare",
+                                name=data['name'],
+                                min_ram=data['minimum_ram'],
+                                min_disk=data['minimum_disk'],
+                                description=data['description'],
+                                architecture=data['architecture']).\
+            AndReturn(image)
         self.mox.ReplayAll()
         url = reverse('horizon:project:images:images:update',
                       args=[image.id])
@@ -168,7 +231,7 @@ class UpdateImageFormTests(test.TestCase):
         self.assertEqual(res.status_code, 302)
 
 
-class ImageViewTests(test.TestCase):
+class ImageViewTests(test.ResetImageAPIVersionMixin, test.TestCase):
     @test.create_stubs({api.glance: ('image_list_detailed',)})
     def test_image_create_get(self):
         filters = {'disk_format': 'aki'}
@@ -186,8 +249,9 @@ class ImageViewTests(test.TestCase):
         self.assertTemplateUsed(res,
                                 'project/images/images/create.html')
 
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
     @test.create_stubs({api.glance: ('image_create',)})
-    def test_image_create_post_copy_from(self):
+    def test_image_create_post_copy_from_v1(self):
         data = {
             'source_type': u'url',
             'image_url': u'http://cloud-images.ubuntu.com/releases/'
@@ -198,8 +262,9 @@ class ImageViewTests(test.TestCase):
         api_data = {'copy_from': data['image_url']}
         self._test_image_create(data, api_data)
 
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
     @test.create_stubs({api.glance: ('image_create',)})
-    def test_image_create_post_location(self):
+    def test_image_create_post_location_v1(self):
         data = {
             'source_type': u'url',
             'image_url': u'http://cloud-images.ubuntu.com/releases/'
@@ -210,8 +275,21 @@ class ImageViewTests(test.TestCase):
         api_data = {'location': data['image_url']}
         self._test_image_create(data, api_data)
 
+    @override_settings(IMAGES_ALLOW_LOCATION=True)
     @test.create_stubs({api.glance: ('image_create',)})
-    def test_image_create_post_upload(self):
+    def test_image_create_post_location_v2(self):
+        data = {
+            'source_type': u'url',
+            'image_url': u'http://cloud-images.ubuntu.com/releases/'
+                         u'oneiric/release/ubuntu-11.10-server-cloudimg'
+                         u'-amd64-disk1.img'}
+
+        api_data = {'location': data['image_url']}
+        self._test_image_create(data, api_data)
+
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
+    @test.create_stubs({api.glance: ('image_create',)})
+    def test_image_create_post_upload_v1(self):
         temp_file = tempfile.NamedTemporaryFile()
         temp_file.write(b'123')
         temp_file.flush()
@@ -224,7 +302,38 @@ class ImageViewTests(test.TestCase):
         self._test_image_create(data, api_data)
 
     @test.create_stubs({api.glance: ('image_create',)})
-    def test_image_create_post_with_kernel_ramdisk(self):
+    def test_image_create_post_upload_v2(self):
+        temp_file = tempfile.NamedTemporaryFile()
+        temp_file.write(b'123')
+        temp_file.flush()
+        temp_file.seek(0)
+
+        data = {'source_type': u'file',
+                'image_file': temp_file}
+
+        api_data = {'data': IsA(InMemoryUploadedFile)}
+        self._test_image_create(data, api_data)
+
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
+    @test.create_stubs({api.glance: ('image_create',)})
+    def test_image_create_post_with_kernel_ramdisk_v1(self):
+        temp_file = tempfile.NamedTemporaryFile()
+        temp_file.write(b'123')
+        temp_file.flush()
+        temp_file.seek(0)
+
+        data = {
+            'source_type': u'file',
+            'image_file': temp_file,
+            'kernel_id': '007e7d55-fe1e-4c5c-bf08-44b4a496482e',
+            'ramdisk_id': '007e7d55-fe1e-4c5c-bf08-44b4a496482a'
+        }
+
+        api_data = {'data': IsA(InMemoryUploadedFile)}
+        self._test_image_create(data, api_data)
+
+    @test.create_stubs({api.glance: ('image_create',)})
+    def test_image_create_post_with_kernel_ramdisk_v2(self):
         temp_file = tempfile.NamedTemporaryFile()
         temp_file.write(b'123')
         temp_file.flush()
@@ -256,14 +365,22 @@ class ImageViewTests(test.TestCase):
 
         api_data = {'container_format': 'bare',
                     'disk_format': data['disk_format'],
-                    'is_public': True,
                     'protected': False,
                     'min_disk': data['minimum_disk'],
                     'min_ram': data['minimum_ram'],
-                    'properties': {
-                        'description': data['description'],
-                        'architecture': data['architecture']},
                     'name': data['name']}
+        if api.glance.VERSIONS.active < 2:
+            api_data.update({'is_public': True,
+                             'properties': {
+                                 'description': data['description'],
+                                 'architecture': data['architecture']}
+                             })
+        else:
+            api_data.update({'visibility': 'public',
+                             'description': data['description'],
+                             'architecture': data['architecture']
+                             })
+
         api_data.update(extra_api_data)
 
         filters = {'disk_format': 'aki'}
@@ -286,12 +403,9 @@ class ImageViewTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertEqual(res.status_code, 302)
 
-    @test.create_stubs({api.glance: ('image_get',)})
-    def test_image_detail_get(self):
-        image = self.images.first()
-
+    def _test_image_detail_get(self, image):
         api.glance.image_get(IsA(http.HttpRequest), str(image.id)) \
-            .AndReturn(self.images.first())
+            .AndReturn(image)
         self.mox.ReplayAll()
 
         res = self.client.get(reverse('horizon:project:images:images:detail',
@@ -302,10 +416,20 @@ class ImageViewTests(test.TestCase):
         self.assertEqual(res.context['image'].name, image.name)
         self.assertEqual(res.context['image'].protected, image.protected)
 
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
     @test.create_stubs({api.glance: ('image_get',)})
-    def test_image_detail_custom_props_get(self):
-        image = self.images.list()[8]
+    def test_image_detail_get_v1(self):
+        image = self.images.first()
 
+        self._test_image_detail_get(image)
+
+    @test.create_stubs({api.glance: ('image_get',)})
+    def test_image_detail_get_v2(self):
+        image = self.imagesV2.first()
+
+        self._test_image_detail_get(image)
+
+    def _test_image_detail_custom_props_get(self, image):
         api.glance.image_get(IsA(http.HttpRequest), str(image.id)) \
             .AndReturn(image)
         self.mox.ReplayAll()
@@ -320,8 +444,8 @@ class ImageViewTests(test.TestCase):
         self.assertNotIn(('description'), image_keys)
 
         # Test custom properties are sorted
-        self.assertEqual(image_props[0], ('bar', 'bar', 'bar val'))
-        self.assertEqual(image_props[1], ('foo', 'foo', 'foo val'))
+        self.assertLess(image_props.index(('bar', 'bar', 'bar val')),
+                        image_props.index(('foo', 'foo', 'foo val')))
 
         # Test all custom properties appear in template
         self.assertContains(res, '<dt title="bar">bar</dt>')
@@ -329,10 +453,20 @@ class ImageViewTests(test.TestCase):
         self.assertContains(res, '<dt title="foo">foo</dt>')
         self.assertContains(res, '<dd>foo val</dd>')
 
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
     @test.create_stubs({api.glance: ('image_get',)})
-    def test_protected_image_detail_get(self):
-        image = self.images.list()[2]
+    def test_image_detail_custom_props_get_v1(self):
+        image = self.images.list()[8]
 
+        self._test_image_detail_custom_props_get(image)
+
+    @test.create_stubs({api.glance: ('image_get',)})
+    def test_image_detail_custom_props_get_v2(self):
+        image = self.imagesV2.list()[2]
+
+        self._test_image_detail_custom_props_get(image)
+
+    def _test_protected_image_detail_get(self, image):
         api.glance.image_get(IsA(http.HttpRequest), str(image.id)) \
             .AndReturn(image)
         self.mox.ReplayAll()
@@ -344,6 +478,19 @@ class ImageViewTests(test.TestCase):
                                 'horizon/common/_detail.html')
         self.assertEqual(res.context['image'].protected, image.protected)
 
+    @override_settings(OPENSTACK_API_VERSIONS={'image': 1})
+    @test.create_stubs({api.glance: ('image_get',)})
+    def test_protected_image_detail_get_v1(self):
+        image = self.images.list()[2]
+
+        self._test_protected_image_detail_get(image)
+
+    @test.create_stubs({api.glance: ('image_get',)})
+    def test_protected_image_detail_get_v2(self):
+        image = self.imagesV2.list()[1]
+
+        self._test_protected_image_detail_get(image)
+
     @test.create_stubs({api.glance: ('image_get',)})
     def test_image_detail_get_with_exception(self):
         image = self.images.first()
@@ -359,9 +506,8 @@ class ImageViewTests(test.TestCase):
 
     @test.create_stubs({api.glance: ('image_get',)})
     def test_image_update_get(self):
-        image = self.images.first()
-        image.disk_format = "ami"
-        image.is_public = True
+        image = self.images.filter(is_public=True)[0]
+
         api.glance.image_get(IsA(http.HttpRequest), str(image.id)) \
            .AndReturn(image)
         self.mox.ReplayAll()
