@@ -21,15 +21,16 @@ import json
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.core.urlresolvers import reverse_lazy
-from django.http import HttpResponse  # noqa
+from django.http import HttpResponse
 from django.utils.translation import ugettext_lazy as _
-from django.views.generic import View  # noqa
+from django.views.generic import View
 
 from horizon import exceptions
 from horizon import tabs
 from horizon.utils.lazy_encoder import LazyTranslationEncoder
 
 from openstack_dashboard import api
+from openstack_dashboard.dashboards.project.network_topology import forms
 from openstack_dashboard.dashboards.project.network_topology.instances \
     import tables as instances_tables
 from openstack_dashboard.dashboards.project.network_topology.networks \
@@ -44,8 +45,6 @@ from openstack_dashboard.dashboards.project.network_topology \
     import tabs as topology_tabs
 from openstack_dashboard.dashboards.project.network_topology import utils
 
-from openstack_dashboard.dashboards.project.instances import\
-    console as i_console
 from openstack_dashboard.dashboards.project.instances.tables import \
     STATUS_DISPLAY_CHOICES as instance_choices
 from openstack_dashboard.dashboards.project.instances import\
@@ -85,8 +84,10 @@ console_invalid_status = {
 
 
 class TranslationHelper(object):
-    """Helper class to provide the translations of instances, networks,
-    routers and ports from other parts of the code to the network topology
+    """Helper class to provide the translations.
+
+    This allows the network topology to access the translated strings
+    for various resources defined in other parts of the code.
     """
     def __init__(self):
         # turn translation tuples into dicts for easy access
@@ -118,8 +119,9 @@ class NTAddInterfaceView(p_views.AddInterfaceView):
 
 
 class NTCreateRouterView(r_views.CreateView):
-    template_name = 'project/network_topology/create_router.html'
+    form_class = forms.NTCreateRouterForm
     success_url = reverse_lazy("horizon:project:network_topology:index")
+    submit_url = reverse_lazy("horizon:project:network_topology:createrouter")
     page_title = _("Create a Router")
 
 
@@ -247,12 +249,8 @@ class JSONView(View):
             # Avoid doing extra calls for console if the server is in
             # a invalid status for console connection
             if server.status.lower() not in console_invalid_status:
-                try:
-                    console = i_console.get_console(
-                        request, console_type, server)[0].lower()
-                    server_data['console'] = console
-                except exceptions.NotAvailable:
-                    pass
+                if console_type:
+                    server_data['console'] = 'auto_console'
 
             data.append(server_data)
         self.add_resource_url('horizon:project:instances:detail', data)
