@@ -17,8 +17,8 @@ import django
 from django.core.urlresolvers import reverse
 from django import http
 
-from mox3.mox import IgnoreArg  # noqa
-from mox3.mox import IsA  # noqa
+from mox3.mox import IgnoreArg
+from mox3.mox import IsA
 import six
 
 from openstack_dashboard import api
@@ -34,16 +34,21 @@ class RouterMixin(object):
                       'network_get', 'is_extension_supported',
                       'list_l3_agent_hosting_router'),
     })
-    def _get_detail(self, router, extraroute=True, lookup_l3=False):
+    def _get_detail(self, router, extraroute=True, lookup_l3=False,
+                    support_l3_agent=True):
         api.neutron.is_extension_supported(IsA(http.HttpRequest), 'extraroute')\
             .MultipleTimes().AndReturn(extraroute)
+        if lookup_l3:
+            api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                               'l3_agent_scheduler')\
+                .AndReturn(support_l3_agent)
         api.neutron.router_get(IsA(http.HttpRequest), router.id)\
             .AndReturn(router)
         api.neutron.port_list(IsA(http.HttpRequest),
                               device_id=router.id)\
             .AndReturn([self.ports.first()])
         self._mock_external_network_get(router)
-        if lookup_l3:
+        if lookup_l3 and support_l3_agent:
             agent = self.agents.list()[1]
             api.neutron.list_l3_agent_hosting_router(IsA(http.HttpRequest), router.id)\
                 .AndReturn([agent])
@@ -93,7 +98,7 @@ class RouterTests(RouterMixin, test.TestCase):
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(self.routers.list())
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
         self._mock_external_network_list()
         self.mox.ReplayAll()
@@ -113,7 +118,7 @@ class RouterTests(RouterMixin, test.TestCase):
             tenant_id=self.tenant.id).MultipleTimes().AndRaise(
             self.exceptions.neutron)
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
         self._mock_external_network_list()
         self.mox.ReplayAll()
@@ -133,7 +138,7 @@ class RouterTests(RouterMixin, test.TestCase):
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).MultipleTimes().AndReturn([router])
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
         self._mock_external_network_list(alter_ids=True)
         self.mox.ReplayAll()
@@ -177,7 +182,7 @@ class RouterTests(RouterMixin, test.TestCase):
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(self.routers.list())
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
         self._mock_external_network_list()
         api.neutron.router_list(
@@ -215,7 +220,7 @@ class RouterTests(RouterMixin, test.TestCase):
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(self.routers.list())
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
         self._mock_external_network_list()
         api.neutron.router_list(
@@ -801,7 +806,7 @@ class RouterViewTests(RouterMixin, test.TestCase):
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(self.routers.list())
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
 
         self._mock_external_network_list()
@@ -828,7 +833,7 @@ class RouterViewTests(RouterMixin, test.TestCase):
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(self.routers.list())
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
 
         self._mock_external_network_list()
@@ -855,7 +860,7 @@ class RouterViewTests(RouterMixin, test.TestCase):
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(self.routers.list())
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)) \
+            IsA(http.HttpRequest), targets=('routers', )) \
             .MultipleTimes().AndReturn(quota_data)
 
         self._mock_external_network_list()
