@@ -25,6 +25,8 @@ from openstack_dashboard import policy
 from openstack_dashboard.usage import quotas
 from openstack_dashboard.utils import filters
 
+# TODO(amotoki): [drop-nova-network] Add neutron policy support
+
 
 class DeleteGroup(policy.PolicyTargetMixin, tables.DeleteAction):
 
@@ -45,21 +47,12 @@ class DeleteGroup(policy.PolicyTargetMixin, tables.DeleteAction):
         )
 
     def allowed(self, request, security_group=None):
-        policy_target = self.get_policy_target(request, security_group)
-        if api.base.is_service_enabled(request, "network"):
-            policy_rules = (("network", "delete_security_group"),)
-        else:
-            policy_rules = (("compute", "compute_extension:security_groups"),)
-
-        if not policy.check(policy_rules, request, policy_target):
-            return False
-
         if not security_group:
             return True
         return security_group.name != 'default'
 
     def delete(self, request, obj_id):
-        api.network.security_group_delete(request, obj_id)
+        api.neutron.security_group_delete(request, obj_id)
 
 
 class CreateGroup(tables.LinkAction):
@@ -70,12 +63,8 @@ class CreateGroup(tables.LinkAction):
     icon = "plus"
 
     def allowed(self, request, security_group=None):
-        if api.base.is_service_enabled(request, "network"):
-            policy_rules = (("network", "create_security_group"),)
-        else:
-            policy_rules = (("compute", "compute_extension:security_groups"),)
-
-        usages = quotas.tenant_quota_usages(request)
+        usages = quotas.tenant_quota_usages(request,
+                                            targets=('security_groups', ))
         if usages['security_groups'].get('available', 1) <= 0:
             if "disabled" not in self.classes:
                 self.classes = [c for c in self.classes] + ["disabled"]
@@ -84,7 +73,7 @@ class CreateGroup(tables.LinkAction):
             self.verbose_name = _("Create Security Group")
             self.classes = [c for c in self.classes if c != "disabled"]
 
-        return policy.check(policy_rules, request, target={})
+        return True
 
 
 class EditGroup(policy.PolicyTargetMixin, tables.LinkAction):
@@ -95,15 +84,6 @@ class EditGroup(policy.PolicyTargetMixin, tables.LinkAction):
     icon = "pencil"
 
     def allowed(self, request, security_group=None):
-        policy_target = self.get_policy_target(request, security_group)
-        if api.base.is_service_enabled(request, "network"):
-            policy_rules = (("network", "update_security_group"),)
-        else:
-            policy_rules = (("compute", "compute_extension:security_groups"),)
-
-        if not policy.check(policy_rules, request, policy_target):
-            return False
-
         if not security_group:
             return True
         return security_group.name != 'default'
@@ -115,15 +95,6 @@ class ManageRules(policy.PolicyTargetMixin, tables.LinkAction):
     url = "horizon:project:security_groups:detail"
     icon = "pencil"
 
-    def allowed(self, request, security_group=None):
-        policy_target = self.get_policy_target(request, security_group)
-        if api.base.is_service_enabled(request, "network"):
-            policy_rules = (("network", "get_security_group"),)
-        else:
-            policy_rules = (("compute", "compute_extension:security_groups"),)
-
-        return policy.check(policy_rules, request, policy_target)
-
 
 class SecurityGroupsFilterAction(tables.FilterAction):
 
@@ -136,6 +107,8 @@ class SecurityGroupsFilterAction(tables.FilterAction):
 
 class SecurityGroupsTable(tables.DataTable):
     name = tables.Column("name", verbose_name=_("Name"))
+    security_group_id = tables.Column("id",
+                                      verbose_name=_("Security Group ID"))
     description = tables.Column("description", verbose_name=_("Description"))
 
     def sanitize_id(self, obj_id):
@@ -155,14 +128,6 @@ class CreateRule(tables.LinkAction):
     classes = ("ajax-modal",)
     icon = "plus"
 
-    def allowed(self, request, security_group_rule=None):
-        if api.base.is_service_enabled(request, "network"):
-            policy_rules = (("network", "create_security_group_rule"),)
-        else:
-            policy_rules = (("compute", "compute_extension:security_groups"),)
-
-        return policy.check(policy_rules, request, target={})
-
     def get_link_url(self):
         return reverse(self.url, args=[self.table.kwargs['security_group_id']])
 
@@ -184,16 +149,8 @@ class DeleteRule(tables.DeleteAction):
             count
         )
 
-    def allowed(self, request, security_group_rule=None):
-        if api.base.is_service_enabled(request, "network"):
-            policy_rules = (("network", "delete_security_group_rule"),)
-        else:
-            policy_rules = (("compute", "compute_extension:security_groups"),)
-
-        return policy.check(policy_rules, request, target={})
-
     def delete(self, request, obj_id):
-        api.network.security_group_rule_delete(request, obj_id)
+        api.neutron.security_group_rule_delete(request, obj_id)
 
     def get_success_url(self, request):
         sg_id = self.table.kwargs['security_group_id']
