@@ -17,6 +17,8 @@
 #    under the License.
 
 import cgi
+
+from mox3.mox import IsA
 import six
 
 import django
@@ -24,17 +26,14 @@ from django.conf import settings
 from django.core.urlresolvers import reverse
 from django import http
 
-from mox3.mox import IsA  # noqa
-
 from horizon import exceptions
 from horizon import forms
 
 from openstack_dashboard import api
+from openstack_dashboard.dashboards.project.security_groups import tables
 from openstack_dashboard.test import helpers as test
 from openstack_dashboard.usage import quotas
 
-from openstack_dashboard.dashboards.project.security_groups import tables
-
 
 INDEX_URL = reverse('horizon:project:security_groups:index')
 SG_CREATE_URL = reverse('horizon:project:security_groups:create')
@@ -55,31 +54,30 @@ def strip_absolute_base(uri):
 
 
 class SecurityGroupsViewTests(test.TestCase):
-    secgroup_backend = 'nova'
+    secgroup_backend = 'neutron'
 
     def setUp(self):
         super(SecurityGroupsViewTests, self).setUp()
+
         sec_group = self.security_groups.first()
         self.detail_url = reverse(SG_DETAIL_VIEW, args=[sec_group.id])
         self.edit_url = reverse(SG_ADD_RULE_VIEW, args=[sec_group.id])
         self.update_url = reverse(SG_UPDATE_VIEW, args=[sec_group.id])
 
-    @test.create_stubs({api.network: ('security_group_list',),
-                        api.base: ('is_service_enabled',),
+    @test.create_stubs({api.neutron: ('security_group_list',),
                         quotas: ('tenant_quota_usages',)})
     def test_index(self):
         sec_groups = self.security_groups.list()
         quota_data = self.quota_usages.first()
         quota_data['security_groups']['available'] = 10
 
-        api.network.security_group_list(IsA(http.HttpRequest)) \
+        api.neutron.security_group_list(IsA(http.HttpRequest)) \
             .AndReturn(sec_groups)
-        quotas.tenant_quota_usages(IsA(http.HttpRequest)).MultipleTimes() \
+        quotas.tenant_quota_usages(
+            IsA(http.HttpRequest),
+            targets=('security_groups', )).MultipleTimes() \
             .AndReturn(quota_data)
 
-        api.base.is_service_enabled(IsA(http.HttpRequest), 'network') \
-            .MultipleTimes().AndReturn(True)
-
         self.mox.ReplayAll()
 
         res = self.client.get(INDEX_URL)
@@ -99,25 +97,21 @@ class SecurityGroupsViewTests(test.TestCase):
             all([sec_groups_from_ctx[i].name <= sec_groups_from_ctx[i + 1].name
                  for i in range(len(sec_groups_from_ctx) - 1)]))
 
-    @test.create_stubs({api.network: ('security_group_list',),
-                        quotas: ('tenant_quota_usages',),
-                        api.base: ('is_service_enabled',)})
+    @test.create_stubs({api.neutron: ('security_group_list',),
+                        quotas: ('tenant_quota_usages',)})
     def test_create_button_attributes(self):
         sec_groups = self.security_groups.list()
         quota_data = self.quota_usages.first()
         quota_data['security_groups']['available'] = 10
 
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)) \
             .AndReturn(sec_groups)
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)).MultipleTimes() \
+            IsA(http.HttpRequest),
+            targets=('security_groups', )).MultipleTimes() \
             .AndReturn(quota_data)
 
-        api.base.is_service_enabled(
-            IsA(http.HttpRequest), 'network').MultipleTimes() \
-            .AndReturn(True)
-
         self.mox.ReplayAll()
 
         res = self.client.get(INDEX_URL)
@@ -136,26 +130,22 @@ class SecurityGroupsViewTests(test.TestCase):
         url = 'horizon:project:security_groups:create'
         self.assertEqual(url, create_action.url)
 
-    @test.create_stubs({api.network: ('security_group_list',),
-                        quotas: ('tenant_quota_usages',),
-                        api.base: ('is_service_enabled',)})
+    @test.create_stubs({api.neutron: ('security_group_list',),
+                        quotas: ('tenant_quota_usages',)})
     def _test_create_button_disabled_when_quota_exceeded(self,
                                                          network_enabled):
         sec_groups = self.security_groups.list()
         quota_data = self.quota_usages.first()
         quota_data['security_groups']['available'] = 0
 
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)) \
             .AndReturn(sec_groups)
         quotas.tenant_quota_usages(
-            IsA(http.HttpRequest)).MultipleTimes() \
+            IsA(http.HttpRequest),
+            targets=('security_groups', )).MultipleTimes() \
             .AndReturn(quota_data)
 
-        api.base.is_service_enabled(
-            IsA(http.HttpRequest), 'network').MultipleTimes() \
-            .AndReturn(network_enabled)
-
         self.mox.ReplayAll()
 
         res = self.client.get(INDEX_URL)
@@ -174,17 +164,14 @@ class SecurityGroupsViewTests(test.TestCase):
     def test_create_button_disabled_when_quota_exceeded_neutron_enabled(self):
         self._test_create_button_disabled_when_quota_exceeded(True)
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def _add_security_group_rule_fixture(self, **kwargs):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(
+        api.neutron.security_group_rule_create(
             IsA(http.HttpRequest),
             kwargs.get('sec_group', sec_group.id),
             kwargs.get('ingress', 'ingress'),
@@ -194,14 +181,14 @@ class SecurityGroupsViewTests(test.TestCase):
             kwargs.get('to_port', int(rule.to_port)),
             kwargs.get('cidr', rule.ip_range['cidr']),
             kwargs.get('security_group', u'%s' % sec_group.id)).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         return sec_group, rule
 
-    @test.create_stubs({api.network: ('security_group_get',)})
+    @test.create_stubs({api.neutron: ('security_group_get',)})
     def test_update_security_groups_get(self):
         sec_group = self.security_groups.first()
-        api.network.security_group_get(IsA(http.HttpRequest),
+        api.neutron.security_group_get(IsA(http.HttpRequest),
                                        sec_group.id).AndReturn(sec_group)
         self.mox.ReplayAll()
         res = self.client.get(self.update_url)
@@ -209,7 +196,7 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertEqual(res.context['security_group'].name,
                          sec_group.name)
 
-    @test.create_stubs({api.network: ('security_group_update',
+    @test.create_stubs({api.neutron: ('security_group_update',
                                       'security_group_get')})
     def test_update_security_groups_post(self):
         """Ensure that we can change a group name.
@@ -220,12 +207,12 @@ class SecurityGroupsViewTests(test.TestCase):
         """
         sec_group = self.security_groups.first()
         sec_group.name = "@new name"
-        api.network.security_group_update(
+        api.neutron.security_group_update(
             IsA(http.HttpRequest),
             str(sec_group.id),
             sec_group.name,
             sec_group.description).AndReturn(sec_group)
-        api.network.security_group_get(
+        api.neutron.security_group_get(
             IsA(http.HttpRequest), sec_group.id).AndReturn(sec_group)
         self.mox.ReplayAll()
         form_data = {'method': 'UpdateGroup',
@@ -244,8 +231,7 @@ class SecurityGroupsViewTests(test.TestCase):
         self._create_security_group(sec_group)
 
     def test_create_security_groups_special_chars(self):
-        """Ensure that a group name is not restricted to alphanumeric
-        characters.
+        """Ensure non-alphanumeric characters can be used as a group name.
 
         bug #1233501 Security group names cannot contain at characters
         bug #1224576 Security group names cannot contain spaces
@@ -254,9 +240,9 @@ class SecurityGroupsViewTests(test.TestCase):
         sec_group.name = '@group name-\xe3\x82\xb3'
         self._create_security_group(sec_group)
 
-    @test.create_stubs({api.network: ('security_group_create',)})
+    @test.create_stubs({api.neutron: ('security_group_create',)})
     def _create_security_group(self, sec_group):
-        api.network.security_group_create(
+        api.neutron.security_group_create(
             IsA(http.HttpRequest),
             sec_group.name,
             sec_group.description).AndReturn(sec_group)
@@ -268,10 +254,10 @@ class SecurityGroupsViewTests(test.TestCase):
         res = self.client.post(SG_CREATE_URL, form_data)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.network: ('security_group_create',)})
+    @test.create_stubs({api.neutron: ('security_group_create',)})
     def test_create_security_groups_post_exception(self):
         sec_group = self.security_groups.first()
-        api.network.security_group_create(
+        api.neutron.security_group_create(
             IsA(http.HttpRequest),
             sec_group.name,
             sec_group.description).AndRaise(self.exceptions.nova)
@@ -284,21 +270,21 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertMessageCount(error=1)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.network: ('security_group_get',)})
+    @test.create_stubs({api.neutron: ('security_group_get',)})
     def test_detail_get(self):
         sec_group = self.security_groups.first()
 
-        api.network.security_group_get(IsA(http.HttpRequest),
+        api.neutron.security_group_get(IsA(http.HttpRequest),
                                        sec_group.id).AndReturn(sec_group)
         self.mox.ReplayAll()
         res = self.client.get(self.detail_url)
         self.assertTemplateUsed(res, SG_DETAIL_TEMPLATE)
 
-    @test.create_stubs({api.network: ('security_group_get',)})
+    @test.create_stubs({api.neutron: ('security_group_get',)})
     def test_detail_get_exception(self):
         sec_group = self.security_groups.first()
 
-        api.network.security_group_get(
+        api.neutron.security_group_get(
             IsA(http.HttpRequest),
             sec_group.id).AndRaise(self.exceptions.nova)
         self.mox.ReplayAll()
@@ -387,17 +373,14 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_detail_add_rule_cidr_with_template(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(IsA(http.HttpRequest),
+        api.neutron.security_group_rule_create(IsA(http.HttpRequest),
                                                sec_group.id,
                                                'ingress', 'IPv4',
                                                rule.ip_protocol,
@@ -405,7 +388,7 @@ class SecurityGroupsViewTests(test.TestCase):
                                                int(rule.to_port),
                                                rule.ip_range['cidr'],
                                                None).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -419,19 +402,19 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertRedirectsNoFollow(res, self.detail_url)
 
     def _get_source_group_rule(self):
-        return self.security_group_rules.get(id=3)
+        for rule in self.security_group_rules.list():
+            if rule.group:
+                return rule
+        raise Exception("No matches found.")
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list',)})
     def test_detail_add_rule_self_as_source_group(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self._get_source_group_rule()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(
+        api.neutron.security_group_rule_create(
             IsA(http.HttpRequest),
             sec_group.id,
             'ingress',
@@ -442,7 +425,7 @@ class SecurityGroupsViewTests(test.TestCase):
             int(rule.to_port),
             None,
             u'%s' % sec_group.id).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -457,17 +440,14 @@ class SecurityGroupsViewTests(test.TestCase):
         res = self.client.post(self.edit_url, formData)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list',)})
     def test_detail_add_rule_self_as_source_group_with_template(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self._get_source_group_rule()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(
+        api.neutron.security_group_rule_create(
             IsA(http.HttpRequest),
             sec_group.id,
             'ingress',
@@ -478,7 +458,7 @@ class SecurityGroupsViewTests(test.TestCase):
             int(rule.to_port),
             None,
             u'%s' % sec_group.id).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -492,21 +472,16 @@ class SecurityGroupsViewTests(test.TestCase):
         res = self.client.post(self.edit_url, formData)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_list',)})
     def test_detail_invalid_port(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         if django.VERSION >= (1, 9):
-            api.network.security_group_backend(
-                IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-            api.network.security_group_list(
+            api.neutron.security_group_list(
                 IsA(http.HttpRequest)).AndReturn(sec_group_list)
 
         self.mox.ReplayAll()
@@ -522,23 +497,18 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertNoMessages()
         self.assertContains(res, "The specified port is invalid")
 
-    @test.create_stubs({api.network: ('security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_list',)})
     def test_detail_invalid_port_range(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
         for i in range(3):
-            api.network.security_group_backend(
-                IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-            api.network.security_group_list(
+            api.neutron.security_group_list(
                 IsA(http.HttpRequest)).AndReturn(sec_group_list)
         if django.VERSION >= (1, 9):
             for i in range(3):
-                api.network.security_group_backend(
-                    IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-                api.network.security_group_list(
+                api.neutron.security_group_list(
                     IsA(http.HttpRequest)).AndReturn(sec_group_list)
 
         self.mox.ReplayAll()
@@ -581,9 +551,8 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertContains(res, cgi.escape('"to" port number is invalid',
                                             quote=True))
 
-    @test.create_stubs({api.network: ('security_group_get',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_get',
+                                      'security_group_list')})
     def test_detail_invalid_icmp_rule(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
@@ -595,9 +564,7 @@ class SecurityGroupsViewTests(test.TestCase):
             call_post *= 2
 
         for i in range(call_post):
-            api.network.security_group_backend(
-                IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-            api.network.security_group_list(
+            api.neutron.security_group_list(
                 IsA(http.HttpRequest)).AndReturn(sec_group_list)
 
         self.mox.ReplayAll()
@@ -663,17 +630,14 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertContains(
             res, "ICMP code is provided but ICMP type is missing.")
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_detail_add_rule_exception(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(
+        api.neutron.security_group_rule_create(
             IsA(http.HttpRequest),
             sec_group.id, 'ingress', 'IPv4',
             rule.ip_protocol,
@@ -681,7 +645,7 @@ class SecurityGroupsViewTests(test.TestCase):
             int(rule.to_port),
             rule.ip_range['cidr'],
             None).AndRaise(self.exceptions.nova)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -695,17 +659,14 @@ class SecurityGroupsViewTests(test.TestCase):
         res = self.client.post(self.edit_url, formData)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_detail_add_rule_duplicated(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(
+        api.neutron.security_group_rule_create(
             IsA(http.HttpRequest),
             sec_group.id, 'ingress', 'IPv4',
             rule.ip_protocol,
@@ -713,7 +674,7 @@ class SecurityGroupsViewTests(test.TestCase):
             int(rule.to_port),
             rule.ip_range['cidr'],
             None).AndRaise(exceptions.Conflict)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -728,12 +689,12 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_delete',)})
+    @test.create_stubs({api.neutron: ('security_group_rule_delete',)})
     def test_detail_delete_rule(self):
         sec_group = self.security_groups.first()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_rule_delete(IsA(http.HttpRequest), rule.id)
+        api.neutron.security_group_rule_delete(IsA(http.HttpRequest), rule.id)
         self.mox.ReplayAll()
 
         form_data = {"action": "rules__delete__%s" % rule.id}
@@ -744,12 +705,12 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertEqual(strip_absolute_base(handled['location']),
                          self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_delete',)})
+    @test.create_stubs({api.neutron: ('security_group_rule_delete',)})
     def test_detail_delete_rule_exception(self):
         sec_group = self.security_groups.first()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_rule_delete(
+        api.neutron.security_group_rule_delete(
             IsA(http.HttpRequest),
             rule.id).AndRaise(self.exceptions.nova)
         self.mox.ReplayAll()
@@ -763,11 +724,11 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertEqual(strip_absolute_base(handled['location']),
                          self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_delete',)})
+    @test.create_stubs({api.neutron: ('security_group_delete',)})
     def test_delete_group(self):
         sec_group = self.security_groups.get(name="other_group")
 
-        api.network.security_group_delete(IsA(http.HttpRequest), sec_group.id)
+        api.neutron.security_group_delete(IsA(http.HttpRequest), sec_group.id)
         self.mox.ReplayAll()
 
         form_data = {"action": "security_groups__delete__%s" % sec_group.id}
@@ -777,11 +738,11 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertEqual(strip_absolute_base(handled['location']),
                          INDEX_URL)
 
-    @test.create_stubs({api.network: ('security_group_delete',)})
+    @test.create_stubs({api.neutron: ('security_group_delete',)})
     def test_delete_group_exception(self):
         sec_group = self.security_groups.get(name="other_group")
 
-        api.network.security_group_delete(
+        api.neutron.security_group_delete(
             IsA(http.HttpRequest),
             sec_group.id).AndRaise(self.exceptions.nova)
 
@@ -795,75 +756,18 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertEqual(strip_absolute_base(handled['location']),
                          INDEX_URL)
 
-
-class SecurityGroupsNovaNeutronDriverTests(SecurityGroupsViewTests):
-    secgroup_backend = 'nova'
-
-    def setUp(self):
-        super(SecurityGroupsNovaNeutronDriverTests, self).setUp()
-
-        self._sec_groups_orig = self.security_groups
-        self.security_groups = self.security_groups_uuid
-
-        self._sec_group_rules_orig = self.security_group_rules
-        self.security_group_rules = self.security_group_rules_uuid
-
-        sec_group = self.security_groups.first()
-        self.detail_url = reverse(SG_DETAIL_VIEW, args=[sec_group.id])
-        self.edit_url = reverse(SG_ADD_RULE_VIEW, args=[sec_group.id])
-        self.update_url = reverse(SG_UPDATE_VIEW, args=[sec_group.id])
-
-    def tearDown(self):
-        self.security_groups = self._sec_groups_orig
-        self.security_group_rules = self._sec_group_rules_orig
-        super(SecurityGroupsNovaNeutronDriverTests, self).tearDown()
-
-
-class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
-    secgroup_backend = 'neutron'
-
-    def setUp(self):
-        super(SecurityGroupsNeutronTests, self).setUp()
-
-        self._sec_groups_orig = self.security_groups
-        self.security_groups = self.q_secgroups
-
-        self._sec_group_rules_orig = self.security_group_rules
-        self.security_group_rules = self.q_secgroup_rules
-
-        sec_group = self.security_groups.first()
-        self.detail_url = reverse(SG_DETAIL_VIEW, args=[sec_group.id])
-        self.edit_url = reverse(SG_ADD_RULE_VIEW, args=[sec_group.id])
-        self.update_url = reverse(SG_UPDATE_VIEW, args=[sec_group.id])
-
-    def tearDown(self):
-        self.security_groups = self._sec_groups_orig
-        self.security_group_rules = self._sec_group_rules_orig
-        super(SecurityGroupsNeutronTests, self).tearDown()
-
-    def _get_source_group_rule(self):
-        for rule in self.security_group_rules.list():
-            if rule.group:
-                return rule
-        raise Exception("No matches found.")
-
-    # Additional tests for Neutron Security Group original features
-
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_detail_add_rule_custom_protocol(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(IsA(http.HttpRequest),
+        api.neutron.security_group_rule_create(IsA(http.HttpRequest),
                                                sec_group.id, 'ingress', 'IPv6',
                                                37, None, None, 'fe80::/48',
                                                None).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -878,21 +782,18 @@ class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
         res = self.client.post(self.edit_url, formData)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_detail_add_rule_egress(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(IsA(http.HttpRequest),
+        api.neutron.security_group_rule_create(IsA(http.HttpRequest),
                                                sec_group.id, 'egress', 'IPv4',
                                                'udp', 80, 80, '10.1.1.0/24',
                                                None).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -907,24 +808,21 @@ class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
         res = self.client.post(self.edit_url, formData)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_detail_add_rule_egress_with_all_tcp(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self.security_group_rules.list()[3]
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(IsA(http.HttpRequest),
+        api.neutron.security_group_rule_create(IsA(http.HttpRequest),
                                                sec_group.id, 'egress', 'IPv4',
                                                rule.ip_protocol,
                                                int(rule.from_port),
                                                int(rule.to_port),
                                                rule.ip_range['cidr'],
                                                None).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -938,17 +836,14 @@ class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
         res = self.client.post(self.edit_url, formData)
         self.assertRedirectsNoFollow(res, self.detail_url)
 
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_detail_add_rule_source_group_with_direction_ethertype(self):
         sec_group = self.security_groups.first()
         sec_group_list = self.security_groups.list()
         rule = self._get_source_group_rule()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        api.network.security_group_rule_create(
+        api.neutron.security_group_rule_create(
             IsA(http.HttpRequest),
             sec_group.id,
             'egress',
@@ -959,7 +854,7 @@ class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
             int(rule.to_port),
             None,
             u'%s' % sec_group.id).AndReturn(rule)
-        api.network.security_group_list(
+        api.neutron.security_group_list(
             IsA(http.HttpRequest)).AndReturn(sec_group_list)
         self.mox.ReplayAll()
 
@@ -978,13 +873,10 @@ class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
 
     @test.update_settings(
         OPENSTACK_NEUTRON_NETWORK={'enable_ipv6': False})
-    @test.create_stubs({api.network: ('security_group_rule_create',
-                                      'security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
     def test_add_rule_ethertype_with_ipv6_disabled(self):
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
         self.mox.ReplayAll()
 
         res = self.client.get(self.edit_url)
@@ -1004,17 +896,10 @@ class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
 
     @test.update_settings(
         OPENSTACK_NEUTRON_NETWORK={'enable_ipv6': False})
-    @test.create_stubs({api.network: ('security_group_list',
-                                      'security_group_backend')})
+    @test.create_stubs({api.neutron: ('security_group_list',)})
     def test_add_rule_cidr_with_ipv6_disabled(self):
         sec_group = self.security_groups.first()
 
-        api.network.security_group_backend(
-            IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-        if django.VERSION >= (1, 9):
-            api.network.security_group_backend(
-                IsA(http.HttpRequest)).AndReturn(self.secgroup_backend)
-
         self.mox.ReplayAll()
 
         formData = {'method': 'AddRule',
@@ -1029,3 +914,83 @@ class SecurityGroupsNeutronTests(SecurityGroupsViewTests):
         res = self.client.post(self.edit_url, formData)
         self.assertFormError(res, 'form', 'cidr',
                              'Invalid version for IP address')
+
+    @test.create_stubs({api.neutron: ('security_group_list',)})
+    def test_detail_add_rule_invalid_port(self):
+        sec_group = self.security_groups.first()
+        sec_group_list = self.security_groups.list()
+        rule = self.security_group_rules.first()
+
+        api.neutron.security_group_list(
+            IsA(http.HttpRequest)).AndReturn(sec_group_list)
+        if django.VERSION >= (1, 9):
+            api.neutron.security_group_list(
+                IsA(http.HttpRequest)).AndReturn(sec_group_list)
+
+        self.mox.ReplayAll()
+
+        formData = {'method': 'AddRule',
+                    'id': sec_group.id,
+                    'port_or_range': 'port',
+                    'port': -1,
+                    'rule_menu': rule.ip_protocol,
+                    'cidr': rule.ip_range['cidr'],
+                    'remote': 'cidr'}
+        res = self.client.post(self.edit_url, formData)
+        self.assertNoMessages()
+        self.assertContains(res, "Not a valid port number")
+
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
+    def test_detail_add_rule_ingress_tcp_without_port(self):
+        sec_group = self.security_groups.first()
+        sec_group_list = self.security_groups.list()
+        rule = self.security_group_rules.list()[3]
+
+        api.neutron.security_group_rule_create(IsA(http.HttpRequest),
+                                               sec_group.id, 'ingress', 'IPv4',
+                                               'tcp',
+                                               None,
+                                               None,
+                                               rule.ip_range['cidr'],
+                                               None).AndReturn(rule)
+        api.neutron.security_group_list(
+            IsA(http.HttpRequest)).AndReturn(sec_group_list)
+        self.mox.ReplayAll()
+
+        formData = {'id': sec_group.id,
+                    'direction': 'ingress',
+                    'port_or_range': 'all',
+                    'rule_menu': 'tcp',
+                    'cidr': rule.ip_range['cidr'],
+                    'remote': 'cidr'}
+        res = self.client.post(self.edit_url, formData)
+        self.assertRedirectsNoFollow(res, self.detail_url)
+
+    @test.create_stubs({api.neutron: ('security_group_rule_create',
+                                      'security_group_list')})
+    def test_detail_add_rule_custom_without_protocol(self):
+        sec_group = self.security_groups.first()
+        sec_group_list = self.security_groups.list()
+        rule = self.security_group_rules.list()[3]
+
+        api.neutron.security_group_rule_create(IsA(http.HttpRequest),
+                                               sec_group.id, 'ingress', 'IPv4',
+                                               None,
+                                               None,
+                                               None,
+                                               rule.ip_range['cidr'],
+                                               None).AndReturn(rule)
+        api.neutron.security_group_list(
+            IsA(http.HttpRequest)).AndReturn(sec_group_list)
+        self.mox.ReplayAll()
+
+        formData = {'id': sec_group.id,
+                    'direction': 'ingress',
+                    'port_or_range': 'port',
+                    'rule_menu': 'custom',
+                    'ip_protocol': -1,
+                    'cidr': rule.ip_range['cidr'],
+                    'remote': 'cidr'}
+        res = self.client.post(self.edit_url, formData)
+        self.assertRedirectsNoFollow(res, self.detail_url)
