@@ -19,7 +19,11 @@
 
     var deleteModalService = {
       open: function () {
-        return;
+        deferredModal.resolve({
+          pass: [{context: {id: 'a'}}],
+          fail: [{context: {id: 'b'}}]
+        });
+        return deferredModal.promise;
       }
     };
 
@@ -39,14 +43,7 @@
       }
     };
 
-    var userSession = {
-      isCurrentProject: function() {
-        deferred.resolve();
-        return deferred.promise;
-      }
-    };
-
-    var deferred, service, $scope;
+    var service, $scope, deferredModal;
 
     ///////////////////////
 
@@ -61,15 +58,13 @@
     beforeEach(module('horizon.app.core.openstack-service-api', function($provide) {
       $provide.value('horizon.app.core.openstack-service-api.glance', glanceAPI);
       $provide.value('horizon.app.core.openstack-service-api.policy', policyAPI);
-      $provide.value('horizon.app.core.openstack-service-api.userSession', userSession);
       spyOn(policyAPI, 'ifAllowed').and.callThrough();
-      spyOn(userSession, 'isCurrentProject').and.callThrough();
     }));
 
     beforeEach(inject(function($injector, _$rootScope_, $q) {
       $scope = _$rootScope_.$new();
       service = $injector.get('horizon.app.core.images.actions.delete-image.service');
-      deferred = $q.defer();
+      deferredModal = $q.defer();
     }));
 
     function generateImage(imageCount) {
@@ -85,7 +80,7 @@
 
       for (var index = 0; index < imageCount; index++) {
         var image = angular.copy(data);
-        image.id = (index + 1);
+        image.id = index + 1;
         image.name = 'image' + (index + 1);
         images.push(image);
       }
@@ -95,7 +90,7 @@
     describe('perform method', function() {
 
       beforeEach(function() {
-        spyOn(deleteModalService, 'open');
+        spyOn(deleteModalService, 'open').and.callThrough();
         service.initScope($scope, labelize);
       });
 
@@ -112,17 +107,28 @@
       ////////////
 
       it('should open the delete modal and show correct labels', testSingleLabels);
+      it('should open the delete modal and show correct labels, one object', testSingleObject);
       it('should open the delete modal and show correct labels', testpluralLabels);
       it('should open the delete modal with correct entities', testEntities);
-      it('should pass the success and error events to be thrown', testEvents);
       it('should only delete images that are valid', testValids);
-      it('should fail if this project is not owner', testOwner);
       it('should fail if images is protected', testProtected);
       it('should fail if status is deleted', testStatus);
       it('should pass in a function that deletes an image', testGlance);
 
       ////////////
 
+      function testSingleObject() {
+        var images = generateImage(1);
+        service.perform(images[0]);
+        $scope.$apply();
+
+        var labels = deleteModalService.open.calls.argsFor(0)[2].labels;
+        expect(deleteModalService.open).toHaveBeenCalled();
+        angular.forEach(labels, function eachLabel(label) {
+          expect(label.toLowerCase()).toContain('image');
+        });
+      }
+
       function testSingleLabels() {
         var images = generateImage(1);
         service.perform(images);
@@ -130,7 +136,9 @@
 
         var labels = deleteModalService.open.calls.argsFor(0)[2].labels;
         expect(deleteModalService.open).toHaveBeenCalled();
-        for (var k in labels) { expect(labels[k].toLowerCase()).toContain('image'); }
+        angular.forEach(labels, function eachLabel(label) {
+          expect(label.toLowerCase()).toContain('image');
+        });
       }
 
       function testpluralLabels() {
@@ -140,7 +148,9 @@
 
         var labels = deleteModalService.open.calls.argsFor(0)[2].labels;
         expect(deleteModalService.open).toHaveBeenCalled();
-        for (var k in labels) { expect(labels[k].toLowerCase()).toContain('images'); }
+        angular.forEach(labels, function eachLabel(label) {
+          expect(label.toLowerCase()).toContain('images');
+        });
       }
 
       function testEntities() {
@@ -154,16 +164,6 @@
         expect(entities.length).toEqual(imageCount);
       }
 
-      function testEvents() {
-        var images = generateImage(1);
-        service.perform(images);
-        $scope.$apply();
-
-        var context = deleteModalService.open.calls.argsFor(0)[2];
-        expect(deleteModalService.open).toHaveBeenCalled();
-        expect(context.successEvent).toEqual('horizon.app.core.images.DELETE_SUCCESS');
-      }
-
       function testValids() {
         var imageCount = 2;
         var images = generateImage(imageCount);
@@ -177,15 +177,6 @@
         expect(entities[1].name).toEqual('image2');
       }
 
-      function testOwner() {
-        var images = generateImage(1);
-        deferred.reject();
-        service.perform(images);
-        $scope.$apply();
-
-        expect(deleteModalService.open).not.toHaveBeenCalled();
-      }
-
       function testProtected() {
         var images = generateImage(1);
         images[0].protected = true;
@@ -238,7 +229,6 @@
       it('should use default policy if batch action', testBatch);
       it('allows delete if image can be deleted', testValid);
       it('disallows delete if image is protected', testProtected);
-      it('disallows delete if image is not owned by user', testOwner);
       it('disallows delete if image status is deleted', testStatus);
 
       ////////////
@@ -266,14 +256,6 @@
         expect(resolver.error).toHaveBeenCalled();
       }
 
-      function testOwner() {
-        var image = generateImage(1)[0];
-        deferred.reject();
-        service.allowed(image).then(resolver.success, resolver.error);
-        $scope.$apply();
-        expect(resolver.error).toHaveBeenCalled();
-      }
-
       function testStatus() {
         var image = generateImage(1)[0];
         image.status = 'deleted';
