@@ -35,14 +35,19 @@
    */
   function neutronAPI(apiService, toastService) {
     var service = {
-      getNetworks: getNetworks,
       createNetwork: createNetwork,
-      getSubnets: getSubnets,
       createSubnet: createSubnet,
-      getPorts: getPorts,
+      deleteTrunk: deleteTrunk,
       getAgents: getAgents,
-      getExtensions: getExtensions,
       getDefaultQuotaSets: getDefaultQuotaSets,
+      getExtensions: getExtensions,
+      getNetworks: getNetworks,
+      getPorts: getPorts,
+      getQosPolicy: getQosPolicy,
+      getQoSPolicies: getQoSPolicies,
+      getSubnets: getSubnets,
+      getTrunk: getTrunk,
+      getTrunks: getTrunks,
       updateProjectQuota: updateProjectQuota
     };
 
@@ -50,6 +55,15 @@
 
     /////////////
 
+    // NOTE(bence romsics): Technically we replace ISO 8061 time stamps with
+    // date objects. We do this because the date objects will stringify to human
+    // readable datetimes in local time (ie. in the browser's time zone) when
+    // displayed.
+    function convertDatesHumanReadable(apidict) {
+      apidict.created_at = new Date(apidict.created_at);
+      apidict.updated_at = new Date(apidict.updated_at);
+    }
+
     // Neutron Services
 
     /**
@@ -94,7 +108,6 @@
      * {
      *    "name": "myNewNetwork",
      *    "admin_state_up": true,
-     *    "net_profile_id" : "asdsarafssdaser",
      *    "shared": true,
      *    "tenant_id": "4fd44f30292945e481c7b8a0c8908869
      * }
@@ -108,9 +121,6 @@
      * The administrative state of the network, which is up (true) or
      * down (false). Optional.
      *
-     * @property {string} newNetwork.net_profile_id
-     * The network profile id. Optional.
-     *
      * @property {boolean} newNetwork.shared
      * Indicates whether this network is shared across all tenants.
      * By default, only adminstative users can change this value. Optional.
@@ -325,7 +335,7 @@
      * @description
      * Update a single project quota data.
      * @param {application/json} quota
-     * A JSON object with the atributes to set to new quota values.
+     * A JSON object with the attributes to set to new quota values.
      * @param {string} projectId
      * Specifies the id of the project that'll have the quota data updated.
      */
@@ -336,6 +346,94 @@
           toastService.add('error', gettext('Unable to update project quota data.'));
         });
     }
-  }
 
+    // QoS policies
+
+    /**
+     * @name horizon.app.core.openstack-service-api.neutron.getQosPolicy
+     * @description get a single qos policy by ID.
+     * @param {string} id
+     * Specifies the id of the policy to request.
+     * @returns {Object} The result of the API call
+     */
+    function getQosPolicy(id) {
+      return apiService.get('/api/neutron/qos_policy/' + id + '/')
+        .error(function () {
+          toastService.add('error', gettext('Unable to retrieve the qos policy.'));
+        });
+    }
+
+    /**
+     * @name horizon.app.core.openstack-service-api.neutron.getQoSPolicies
+     * @description get a list of qos policies.
+     *
+     * The listing result is an object with property "items". Each item is
+     * a QoS policy.
+     */
+    function getQoSPolicies() {
+      return apiService.get('/api/neutron/qos_policies/')
+        .error(function () {
+          toastService.add('error', gettext('Unable to retrieve the qos policies.'));
+        });
+    }
+
+    // Trunks
+
+    /**
+     * @name getTrunk
+     * @description
+     * Get a single trunk by ID
+     *
+     * @param {string} id
+     * Specifies the id of the trunk to request.
+     *
+     * @returns {Object} The result of the API call
+     */
+    function getTrunk(id) {
+      return apiService.get('/api/neutron/trunks/' + id + '/')
+        .success(function(trunk) {
+          convertDatesHumanReadable(trunk);
+        })
+        .error(function () {
+          var msg = gettext('Unable to retrieve the trunk with id: %(id)s');
+          toastService.add('error', interpolate(msg, { id : id }, true));
+        });
+    }
+
+    /**
+     * @name getTrunks
+     * @description
+     * Get a list of trunks for a tenant.
+     *
+     * @returns {Object} An object with property "items". Each item is a trunk.
+     */
+    function getTrunks(params) {
+      var config = params ? {'params' : params} : {};
+      return apiService.get('/api/neutron/trunks/', config)
+        .success(function(trunks) {
+          trunks.items.forEach(function(trunk) {
+            convertDatesHumanReadable(trunk);
+          });
+        })
+        .error(function () {
+          toastService.add('error', gettext('Unable to retrieve the trunks.'));
+        });
+    }
+
+    /**
+     * @name deleteTrunk
+     * @description
+     * Delete a single neutron trunk.
+     * @param {string} trunkId
+     * UUID of a trunk to be deleted.
+     */
+    function deleteTrunk(trunkId) {
+      var promise = apiService.delete('/api/neutron/trunks/' + trunkId + '/');
+
+      return promise.error(function() {
+        var msg = gettext('Unable to delete trunk: %(id)s');
+        toastService.add('error', interpolate(msg, { id: trunkId }, true));
+      });
+    }
+  }
 }());
