@@ -18,24 +18,24 @@
 
 import collections
 import copy
-from functools import wraps  # noqa
+from functools import wraps
+from importlib import import_module
 import os
 import traceback
 import unittest
 
 import django
 from django.conf import settings
-from django.contrib.messages.storage import default_storage  # noqa
+from django.contrib.messages.storage import default_storage
 from django.core.handlers import wsgi
 from django.core import urlresolvers
-from django.test.client import RequestFactory  # noqa
+from django.test.client import RequestFactory
 from django.test import utils as django_test_utils
 from django.utils import http
 
 from cinderclient import client as cinder_client
 import glanceclient
 from heatclient import client as heat_client
-from importlib import import_module
 from keystoneclient.v2_0 import client as keystone_client
 import mock
 from mox3 import mox
@@ -116,6 +116,23 @@ def create_stubs(stubs_to_create=None):
     return inner_stub_out
 
 
+def _apply_panel_mocks(patchers=None):
+    """Global mocks on panels that get called on all views."""
+    if patchers is None:
+        patchers = {}
+    mocked_methods = getattr(settings, 'TEST_GLOBAL_MOCKS_ON_PANELS', {})
+    for name, mock_config in mocked_methods.items():
+        method = mock_config['method']
+        mock_params = {}
+        for param in ['return_value', 'side_effect']:
+            if param in mock_config:
+                mock_params[param] = mock_config[param]
+        patcher = mock.patch(method, **mock_params)
+        patcher.start()
+        patchers[name] = patcher
+    return patchers
+
+
 class RequestFactoryWithMessages(RequestFactory):
     def get(self, *args, **kwargs):
         req = super(RequestFactoryWithMessages, self).get(*args, **kwargs)
@@ -139,18 +156,18 @@ class TestCase(horizon_helpers.TestCase):
 
     It gives access to numerous additional features:
 
-      * A full suite of test data through various attached objects and
-        managers (e.g. ``self.servers``, ``self.user``, etc.). See the
-        docs for
-        :class:`~openstack_dashboard.test.test_data.utils.TestData`
-        for more information.
-      * The ``mox`` mocking framework via ``self.mox``.
-      * A set of request context data via ``self.context``.
-      * A ``RequestFactory`` class which supports Django's ``contrib.messages``
-        framework via ``self.factory``.
-      * A ready-to-go request object via ``self.request``.
-      * The ability to override specific time data controls for easier testing.
-      * Several handy additional assertion methods.
+    * A full suite of test data through various attached objects and
+      managers (e.g. ``self.servers``, ``self.user``, etc.). See the
+      docs for
+      :class:`~openstack_dashboard.test.test_data.utils.TestData`
+      for more information.
+    * The ``mox`` mocking framework via ``self.mox``.
+    * A set of request context data via ``self.context``.
+    * A ``RequestFactory`` class which supports Django's ``contrib.messages``
+      framework via ``self.factory``.
+    * A ready-to-go request object via ``self.request``.
+    * The ability to override specific time data controls for easier testing.
+    * Several handy additional assertion methods.
     """
 
     # To force test failures when unmocked API calls are attempted, provide
@@ -171,15 +188,17 @@ class TestCase(horizon_helpers.TestCase):
         self._real_context_processor = context_processors.openstack
         context_processors.openstack = lambda request: self.context
 
-        self.patchers = {}
-        self.add_panel_mocks()
+        self.patchers = _apply_panel_mocks()
 
         super(TestCase, self).setUp()
 
     def _setup_test_data(self):
         super(TestCase, self)._setup_test_data()
         test_utils.load_test_data(self)
-        self.context = {'authorized_tenants': self.tenants.list()}
+        self.context = {
+            'authorized_tenants': self.tenants.list(),
+            'JS_CATALOG': context_processors.get_js_catalog(settings),
+        }
 
     def _setup_factory(self):
         # For some magical reason we need a copy of this here.
@@ -205,14 +224,6 @@ class TestCase(horizon_helpers.TestCase):
         super(TestCase, self)._setup_request()
         self.request.session['token'] = self.token.id
 
-    def add_panel_mocks(self):
-        """Global mocks on panels that get called on all views."""
-        self.patchers['aggregates'] = mock.patch(
-            'openstack_dashboard.dashboards.admin'
-            '.aggregates.panel.Aggregates.can_access',
-            mock.Mock(return_value=True))
-        self.patchers['aggregates'].start()
-
     def tearDown(self):
         HTTPConnection.connect = self._real_conn_request
         context_processors.openstack = self._real_context_processor
@@ -321,8 +332,8 @@ class TestCase(horizon_helpers.TestCase):
                                     row_actions))
 
         msg_args = (action_name, table_name, row_id)
-        self.assertTrue(
-            len(actions) > 0,
+        self.assertGreater(
+            len(actions), 0,
             "No action named '%s' found in '%s' table for id '%s'" % msg_args)
 
         self.assertEqual(
@@ -339,8 +350,8 @@ class TestCase(horizon_helpers.TestCase):
         actions = list(moves.filter(lambda x: x.name == action_name,
                                     table_actions))
         msg_args = (action_name, table_name)
-        self.assertTrue(
-            len(actions) > 0,
+        self.assertGreater(
+            len(actions), 0,
             "No action named '%s' found in '%s' table" % msg_args)
 
         self.assertEqual(
@@ -409,6 +420,9 @@ class APITestCase(TestCase):
             """
             return self.stub_glanceclient()
 
+        def fake_novaclient(request, version=None):
+            return self.stub_novaclient()
+
         # Store the original clients
         self._original_glanceclient = api.glance.glanceclient
         self._original_keystoneclient = api.keystone.keystoneclient
@@ -420,7 +434,7 @@ class APITestCase(TestCase):
         # Replace the clients with our stubs.
         api.glance.glanceclient = fake_glanceclient
         api.keystone.keystoneclient = fake_keystoneclient
-        api.nova.novaclient = lambda request: self.stub_novaclient()
+        api.nova.novaclient = fake_novaclient
         api.neutron.neutronclient = lambda request: self.stub_neutronclient()
         api.cinder.cinderclient = lambda request: self.stub_cinderclient()
         api.heat.heatclient = (lambda request, password=None:
@@ -532,12 +546,7 @@ class SeleniumTestCase(horizon_helpers.SeleniumTestCase):
                            tenant_id=self.tenant.id,
                            service_catalog=self.service_catalog,
                            authorized_tenants=self.tenants.list())
-        self.patchers = {}
-        self.patchers['aggregates'] = mock.patch(
-            'openstack_dashboard.dashboards.admin'
-            '.aggregates.panel.Aggregates.can_access',
-            mock.Mock(return_value=True))
-        self.patchers['aggregates'].start()
+        self.patchers = _apply_panel_mocks()
         os.environ["HORIZON_TEST_RUN"] = "True"
 
     def tearDown(self):
