@@ -10,7 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import urlparse
+import six.moves.urllib.parse as urlparse
 
 from openstack_dashboard.test.integration_tests import basewebobject
 
@@ -29,11 +29,14 @@ class PageObject(basewebobject.BaseWebObject):
     def page_title(self):
         return self.driver.title
 
-    def is_the_current_page(self):
-        self.assertIn(self._page_title, self.page_title,
-                      "Expected to find %s in page title, instead found: %s"
-                      % (self._page_title, self.page_title))
-        return True
+    def is_the_current_page(self, do_assert=False):
+        found_expected_title = self.page_title.startswith(self._page_title)
+        if do_assert:
+            self.assertTrue(
+                found_expected_title,
+                "Expected to find %s in page title, instead found: %s"
+                % (self._page_title, self.page_title))
+        return found_expected_title
 
     @property
     def login_url(self):
@@ -53,6 +56,7 @@ class PageObject(basewebobject.BaseWebObject):
 
     def switch_window(self, window_name=None, window_index=None):
         """Switches focus between the webdriver windows.
+
         Args:
         - window_name: The name of the window to switch to.
         - window_index: The index of the window handle to switch to.
@@ -87,4 +91,4 @@ class PageObject(basewebobject.BaseWebObject):
 
     def go_to_login_page(self):
         self.driver.get(self.login_url)
-        self.is_the_current_page()
+        self.is_the_current_page(do_assert=True)
